==> qtjambi-httpserver-debuginfo-linux-x64-6.5.3.jar: sources/QtJambiHttpServer/QAbstractHttpServer_shell.h <==
#ifndef QABSTRACTHTTPSERVER_SHELL_H
#define QABSTRACTHTTPSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtHttpServer/qabstracthttpserver.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qssl.h>
#include <QtNetwork/qsslcertificate.h>
#include <QtNetwork/qsslconfiguration.h>
#include <QtNetwork/qsslkey.h>
#include <QtNetwork/qtcpserver.h>
#include <QtWebSockets/qwebsocket.h>
#include <QtJambi/RegistryAPI>


class QAbstractHttpServer_shell : public QAbstractHttpServer, public QtJambiShellInterface
{
public:
    QAbstractHttpServer_shell(QObject* parent0 = nullptr);
    ~QAbstractHttpServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool handleRequest(const QHttpServerRequest& request0, QHttpServerResponder& responder1) override;
    void missingHandler(const QHttpServerRequest& request0, QHttpServerResponder&& responder1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractHttpServer_access : public QAbstractHttpServer
{
    jboolean __qt_handleRequest_cref_QHttpServerRequest_ref_QHttpServerResponder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, QtJambiNativeID responder1);
    void __qt_missingHandler_cref_QHttpServerRequest_rval_QHttpServerResponder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, QtJambiNativeID responder1);
};

#endif // QABSTRACTHTTPSERVER_SHELL_H

==> qtjambi-httpserver-debuginfo-linux-x64-6.5.4.jar: sources/QtJambiHttpServer/QAbstractHttpServer_shell.h <==
#ifndef QABSTRACTHTTPSERVER_SHELL_H
#define QABSTRACTHTTPSERVER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtHttpServer/qabstracthttpserver.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtHttpServer/qhttpserverrequest.h>
#include <QtHttpServer/qhttpserverresponder.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qssl.h>
#if __has_include(<QtNetwork/qsslcertificate.h>)
#include <QtNetwork/qsslcertificate.h>
#endif
#if __has_include(<QtNetwork/qsslconfiguration.h>)
#include <QtNetwork/qsslconfiguration.h>
#endif
#if __has_include(<QtNetwork/qsslkey.h>)
#include <QtNetwork/qsslkey.h>
#endif
#include <QtNetwork/qtcpserver.h>
#include <QtWebSockets/qwebsocket.h>
#include <QtJambi/RegistryAPI>


class QAbstractHttpServer_shell : public QAbstractHttpServer, public QtJambiShellInterface
{
public:
    QAbstractHttpServer_shell(QObject* parent0 = nullptr);
    ~QAbstractHttpServer_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    bool handleRequest(const QHttpServerRequest& request0, QHttpServerResponder& responder1) override;
    void missingHandler(const QHttpServerRequest& request0, QHttpServerResponder&& responder1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QAbstractHttpServer_access : public QAbstractHttpServer
{
    jboolean __qt_handleRequest_cref_QHttpServerRequest_ref_QHttpServerResponder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, QtJambiNativeID responder1);
    void __qt_missingHandler_cref_QHttpServerRequest_rval_QHttpServerResponder(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID request0, QtJambiNativeID responder1);
};

#endif // QABSTRACTHTTPSERVER_SHELL_H
